@@ -10,11 +10,13 @@
 // copyright notice, and modified files need to carry a notice indicating
 // that they have been altered from the originals.
 
+pub mod clifford;
 pub mod convert_2q_block_matrix;
 pub mod pauli_lindblad_map;
 pub mod sparse_observable;
 pub mod sparse_pauli_op;
 pub mod unitary_compose;
+pub mod unitary_sim;
 pub mod versor_u2;
 
 mod rayon_ext;
@@ -23,4 +25,12 @@ mod test;
 
 use pyo3::import_exception;
 
+pub(crate) mod imports {
+    use qiskit_circuit::imports::ImportOnceCell;
+
+    pub static PAULI_TYPE: ImportOnceCell = ImportOnceCell::new("qiskit.quantum_info", "Pauli");
+    pub static PAULI_LIST_TYPE: ImportOnceCell =
+        ImportOnceCell::new("qiskit.quantum_info", "PauliList");
+}
+
 import_exception!(qiskit.exceptions, QiskitError);
