@@ -40,29 +40,30 @@ class PiecewiseChebyshev(BlueprintCircuit):
 
     Examples:
 
-        .. plot::
-           :alt: Circuit diagram output by the previous code.
-           :include-source:
+    .. plot::
+        :alt: Circuit diagram output by the previous code.
+        :include-source:
 
-            import numpy as np
-            from qiskit import QuantumCircuit
-            from qiskit.circuit.library.arithmetic.piecewise_chebyshev import PiecewiseChebyshev
-            f_x, degree, breakpoints, num_state_qubits = lambda x: np.arcsin(1 / x), 2, [2, 4], 2
-            pw_approximation = PiecewiseChebyshev(f_x, degree, breakpoints, num_state_qubits)
-            pw_approximation._build()
-            qc = QuantumCircuit(pw_approximation.num_qubits)
-            qc.h(list(range(num_state_qubits)))
-            qc.append(pw_approximation.to_instruction(), qc.qubits)
-            qc.draw(output='mpl')
+        import numpy as np
+        from qiskit import QuantumCircuit
+        from qiskit.circuit.library.arithmetic.piecewise_chebyshev import PiecewiseChebyshev
+        f_x, degree, breakpoints, num_state_qubits = lambda x: np.arcsin(1 / x), 2, [2, 4], 2
+        pw_approximation = PiecewiseChebyshev(f_x, degree, breakpoints, num_state_qubits)
+        pw_approximation._build()
+        qc = QuantumCircuit(pw_approximation.num_qubits)
+        qc.h(list(range(num_state_qubits)))
+        qc.append(pw_approximation.to_instruction(), qc.qubits)
+        qc.draw(output='mpl')
 
     References:
 
-        [1]: Haener, T., Roetteler, M., & Svore, K. M. (2018).
-             Optimizing Quantum Circuits for Arithmetic.
-             `arXiv:1805.12445 <http://arxiv.org/abs/1805.12445>`_
-        [2]: Carrera Vazquez, A., Hiptmair, H., & Woerner, S. (2022).
-             Enhancing the Quantum Linear Systems Algorithm Using Richardson Extrapolation.
-             `ACM Transactions on Quantum Computing 3, 1, Article 2 <https://doi.org/10.1145/3490631>`_
+    [1] Haener, T., Roetteler, M., & Svore, K. M. (2018).
+    Optimizing Quantum Circuits for Arithmetic.
+    `arXiv:1805.12445 <http://arxiv.org/abs/1805.12445>`_
+
+    [2] Carrera Vazquez, A., Hiptmair, H., & Woerner, S. (2022).
+    Enhancing the Quantum Linear Systems Algorithm Using Richardson Extrapolation.
+    `ACM Transactions on Quantum Computing 3, 1, Article 2 <https://doi.org/10.1145/3490631>`_
     """
 
     def __init__(
@@ -377,7 +378,7 @@ class PiecewiseChebyshevGate(Gate):
             from qiskit import QuantumCircuit
             from qiskit.circuit.library.arithmetic import PiecewiseChebyshevGate
 
-            f_x, num_state_qubits, degree, breakpoints = lambda x: np.sin(1 / x), 2, 2, [2, 4]
+            f_x, num_state_qubits, degree, breakpoints = lambda x: np.arcsin(1 / x), 2, 2, [2, 4]
             pw_approximation = PiecewiseChebyshevGate(f_x, num_state_qubits, degree, breakpoints)
 
             qc = QuantumCircuit(pw_approximation.num_qubits)
@@ -387,12 +388,13 @@ class PiecewiseChebyshevGate(Gate):
 
     References:
 
-        [1]: Haener, T., Roetteler, M., & Svore, K. M. (2018).
-             Optimizing Quantum Circuits for Arithmetic.
-             `arXiv:1805.12445 <http://arxiv.org/abs/1805.12445>`_
-        [2]: Carrera Vazquez, A., Hiptmair, H., & Woerner, S. (2022).
-             Enhancing the Quantum Linear Systems Algorithm Using Richardson Extrapolation.
-             `ACM Transactions on Quantum Computing 3, 1, Article 2 <https://doi.org/10.1145/3490631>`_
+    [1] Haener, T., Roetteler, M., & Svore, K. M. (2018).
+    Optimizing Quantum Circuits for Arithmetic.
+    `arXiv:1805.12445 <http://arxiv.org/abs/1805.12445>`_
+
+    [2] Carrera Vazquez, A., Hiptmair, H., & Woerner, S. (2022).
+    Enhancing the Quantum Linear Systems Algorithm Using Richardson Extrapolation.
+    `ACM Transactions on Quantum Computing 3, 1, Article 2 <https://doi.org/10.1145/3490631>`_
     """
 
     def __init__(
