@@ -28,6 +28,7 @@ from qiskit._accelerate.synthesis.multi_controlled import (
     c4x as c4x_rs,
     synth_mcx_n_dirty_i15 as synth_mcx_n_dirty_i15_rs,
     synth_mcx_noaux_v24 as synth_mcx_noaux_v24_rs,
+    synth_mcx_noaux_hp24 as synth_mcx_noaux_hp24_rs,
 )
 
 
@@ -221,6 +222,29 @@ def synth_mcx_noaux_v24(num_ctrl_qubits: int) -> QuantumCircuit:
     return circ
 
 
+def synth_mcx_noaux_hp24(num_ctrl_qubits: int) -> QuantumCircuit:
+    r"""
+    Synthesize a multi-controlled X gate with :math:`k` controls based on
+    the work by Huang and Palsberg.
+
+    Produces a quantum circuit with :math:`k + 1` qubits. The number of CX-gates
+    is linear in :math:`k`.
+
+    Args:
+        num_ctrl_qubits: The number of control qubits.
+
+    Returns:
+        The synthesized quantum circuit.
+
+    References:
+        1. Huang and Palsberg, *Compiling Conditional Quantum Gates without Using
+           Helper Qubits*, PLDI (2024),
+           <https://dl.acm.org/doi/10.1145/3656436>`_
+    """
+    circ = QuantumCircuit._from_circuit_data(synth_mcx_noaux_hp24_rs(num_ctrl_qubits))
+    return circ
+
+
 def _n_parallel_ccx_x(n: int, apply_x: bool = True) -> QuantumCircuit:
     r"""
     Construct a quantum circuit for creating n-condionally clean ancillae using 3n qubits. This
@@ -357,8 +381,8 @@ def synth_mcx_1_kg24(num_ctrl_qubits: int, clean: bool = True) -> QuantumCircuit
 def synth_mcx_1_clean_kg24(num_ctrl_qubits: int) -> QuantumCircuit:
     r"""
     Synthesize a multi-controlled X gate with :math:`k` controls using :math:`1` clean ancillary qubit
-    producing a circuit with :math:`2k-3` Toffoli gates and depth :math:`O(k)` as described in
-    Sec. 5.1 of [1].
+    producing a circuit with :math:`2k-3` Toffoli gates or :math:`6k-6` CX gates and depth
+    :math:`O(k)` as described in Sec. 5.1 of [1].
 
     Args:
         num_ctrl_qubits: The number of control qubits.
@@ -380,8 +404,8 @@ def synth_mcx_1_clean_kg24(num_ctrl_qubits: int) -> QuantumCircuit:
 def synth_mcx_1_dirty_kg24(num_ctrl_qubits: int) -> QuantumCircuit:
     r"""
     Synthesize a multi-controlled X gate with :math:`k` controls using :math:`1` dirty ancillary qubit
-    producing a circuit with :math:`4k-8` Toffoli gates and depth :math:`O(k)` as described in
-    Sec. 5.3 of [1].
+    producing a circuit with :math:`4k-8` Toffoli gates or :math:`12k-18` CX gates and depth
+    :math:`O(k)` as described in Sec. 5.3 of [1].
 
     Args:
         num_ctrl_qubits: The number of control qubits.
@@ -530,8 +554,8 @@ def synth_mcx_2_kg24(num_ctrl_qubits: int, clean: bool = True) -> QuantumCircuit
 def synth_mcx_2_clean_kg24(num_ctrl_qubits: int) -> QuantumCircuit:
     r"""
     Synthesize a multi-controlled X gate with :math:`k` controls using :math:`2` clean ancillary qubits
-    producing a circuit with :math:`2k-3` Toffoli gates and depth :math:`O(\log(k))` as described in
-    Sec. 5.2 of [1].
+    producing a circuit with :math:`2k-3` Toffoli gates or :math:`6k-6` CX gates and
+    depth :math:`O(\log(k))` as described in Sec. 5.2 of [1].
 
     Args:
         num_ctrl_qubits: The number of control qubits.
@@ -553,8 +577,8 @@ def synth_mcx_2_clean_kg24(num_ctrl_qubits: int) -> QuantumCircuit:
 def synth_mcx_2_dirty_kg24(num_ctrl_qubits: int) -> QuantumCircuit:
     r"""
     Synthesize a multi-controlled X gate with :math:`k` controls using :math:`2` dirty ancillary qubits
-    producing a circuit with :math:`4k-8` Toffoli gates and depth :math:`O(\log(k))` as described in
-    Sec. 5.4 of [1].
+    producing a circuit with :math:`4k-8` Toffoli gates or :math:`12k-18` CX gates and depth
+    :math:`O(\log(k))` as described in Sec. 5.4 of [1].
 
     Args:
         num_ctrl_qubits: The number of control qubits.
