@@ -159,6 +159,38 @@ class Target(BaseTarget):
     angle :class:`~qiskit.circuit.library.RXGate` while ``rx`` will get the
     parameterized :class:`~qiskit.circuit.library.RXGate`.
 
+    You can optionally specify a bound on valid values on a gate in the target
+    by using the ``angle_bounds`` keyword argument when calling the :meth:`.add_instruction`
+    method. Bounds are set on operations not individual instructions, so when
+    you call :meth:`.add_instruction` the bounds are applied for all qargs that it
+    is defined on. The bounds are specified of a list of 2-tuples of floats where
+    the first float is the lower bound and the second float is the upper bound. For example,
+    if you specfied an angle bound::
+
+        [(0.0, 3.14), (-3.14, 3.14), (0.0, 1.0)]
+
+    this indicates the angle bounds for a 3 parameter gate where the first
+    parameter accepts angles between 0 and 3.14, the second between -3.14 and
+    3.14, and the third parameter between 0 and 1. All bounds are set
+    inclusively as well. A bound can also be specified with ``None`` instead
+    of a 2-tuple which indicates that parameter has no constraints. For example::
+
+        [(0.0, 3.14, None, None)]
+
+    indicates an angle bound for a 3 parameter gate where only the first
+    parameter is restricted to angles between 0.0 and 3.14 and the other
+    parameters accept any value.
+
+    You can check if any operations in the target have angle bounds set with,
+    :meth:`.has_angle_bounds` and also if a specific name in the target has
+    angle bounds set with :meth:`.gate_has_angle_bounds`. Whether a particular
+    set of parameter values conforms to the angle bounds can be checked
+    with :meth:`.supported_angle_bound`. In the preset pass managers the
+    :class:`.WrapAngles` pass is used to enforce the angle bounds, for this
+    to work you need to provide a function to the :class:`.WrapAngleRegistry`
+    used by the pass. You can see more details on this in:
+    :ref:`angle-bounds-on-gates`.
+
     This class can be queried via the mapping protocol, using the
     instruction's name as a key. You can modify any property for an
     instruction via the :meth:`.update_instruction_properties` method.
@@ -186,6 +218,8 @@ class Target(BaseTarget):
         "_coupling_graph",
         "_instruction_durations",
         "_instruction_schedule_map",
+        "_non_global_basis_strict",
+        "_non_global_basis",
     )
 
     def __new__(  # pylint: disable=keyword-arg-before-vararg
@@ -199,8 +233,6 @@ class Target(BaseTarget):
         acquire_alignment: int = 1,
         qubit_properties: list | None = None,
         concurrent_measurements: list | None = None,
-        *args,  # pylint: disable=unused-argument disable=keyword-arg-before-vararg
-        **kwargs,  # pylint: disable=unused-argument
     ):
         """
         Create a new ``Target`` object
@@ -246,7 +278,7 @@ class Target(BaseTarget):
         """
         if description is not None:
             description = str(description)
-        return super(Target, cls).__new__(  # pylint: disable=too-many-function-args
+        out = super(Target, cls).__new__(  # pylint: disable=too-many-function-args
             cls,
             description,
             num_qubits,
@@ -258,6 +290,14 @@ class Target(BaseTarget):
             qubit_properties,
             concurrent_measurements,
         )
+        # A nested mapping of gate name -> qargs -> properties
+        out._gate_map = {}
+        out._coupling_graph = None
+        out._instruction_durations = None
+        out._instruction_schedule_map = None
+        out._non_global_basis = None
+        out._non_global_basis_strict = None
+        return out
 
     def __init__(
         self,
@@ -271,11 +311,36 @@ class Target(BaseTarget):
         qubit_properties=None,  # pylint: disable=unused-argument
         concurrent_measurements=None,  # pylint: disable=unused-argument
     ):
-        # A nested mapping of gate name -> qargs -> properties
-        self._gate_map = {}
-        self._coupling_graph = None
-        self._instruction_durations = None
-        self._instruction_schedule_map = None
+        super().__init__()
+
+    def get_non_global_operation_names(self, strict_direction=False):
+        """Return the non-global operation names for the target
+
+        The non-global operations are those in the target which don't apply
+        on all qubits (for single qubit operations) or all multi-qubit qargs
+        (for multi-qubit operations).
+
+        Args:
+            strict_direction (bool): If set to ``True`` the multi-qubit
+                operations considered as non-global respect the strict
+                direction (or order of qubits in the qargs is significant). For
+                example, if ``cx`` is defined on ``(0, 1)`` and ``ecr`` is
+                defined over ``(1, 0)`` by default neither would be considered
+                non-global, but if ``strict_direction`` is set ``True`` both
+                ``cx`` and ``ecr`` would be returned.
+
+        Returns:
+            List[str]: A list of operation names for operations that aren't global in this target
+        """
+        if strict_direction:
+            if self._non_global_basis_strict is None:
+                self._non_global_basis_strict = super()._get_non_global_operation_names(
+                    strict_direction
+                )
+            return self._non_global_basis_strict
+        if self._non_global_basis is None:
+            self._non_global_basis = super()._get_non_global_operation_names(strict_direction)
+        return self._non_global_basis
 
     @property
     def dt(self):
@@ -288,7 +353,7 @@ class Target(BaseTarget):
         self._dt = dt
         self._instruction_durations = None
 
-    def add_instruction(self, instruction, properties=None, name=None):
+    def add_instruction(self, instruction, properties=None, name=None, *, angle_bounds=None):
         """Add a new instruction to the :class:`~qiskit.transpiler.Target`
 
         As ``Target`` objects are strictly additive this is the primary method
@@ -350,6 +415,13 @@ class Target(BaseTarget):
                 parameterization of a single gate by providing a unique name for
                 each (e.g. `"rx30"`, `"rx60", ``"rx90"`` similar to the example in the
                 documentation for the :class:`~qiskit.transpiler.Target` class).
+            angle_bounds (list): The bounds on the parameters for a given gate. This is specified by
+                a list of tuples (low, high) which represent the low and high bound (inclusively) on
+                what float values are allowed for the parameter in that position. If a parameter
+                doesn't have an angle bound you can use ``None`` to represent that. For example if
+                a 3 parameter gate only had a bound on the second parameter you would represent
+                that with: ``[None, [0, 3.14], None]`` which means the first and third parameter
+                allow any value but the second parameter only accepts values between 0 and 3.14.
         Raises:
             AttributeError: If gate is already in map
             TranspilerError: If an operation class is passed in for ``instruction`` and no name
@@ -373,11 +445,15 @@ class Target(BaseTarget):
             properties = {None: None}
         if instruction_name in self._gate_map:
             raise AttributeError(f"Instruction {instruction_name} is already in the target")
-        super().add_instruction(instruction, instruction_name, properties)
+        super().add_instruction(
+            instruction, instruction_name, properties, angle_bounds=angle_bounds
+        )
         self._gate_map[instruction_name] = properties
         self._coupling_graph = None
         self._instruction_durations = None
         self._instruction_schedule_map = None
+        self._non_global_basis_strict = None
+        self._non_global_basis = None
 
     def update_instruction_properties(self, instruction, qargs, properties):
         """Update the property object for an instruction qarg pair already in the Target.
@@ -880,8 +956,46 @@ class _FakeTarget(Target):
     This is intended to replace the use of loose constraints in the pipeline.
     """
 
-    def __init__(self, coupling_map=None, **kwargs):
-        super().__init__(**kwargs)
+    def __new__(
+        cls,
+        coupling_map=None,  # pylint: disable=unused-argument
+        description=None,
+        num_qubits=0,
+        dt=None,
+        granularity=1,
+        min_length=1,
+        pulse_alignment=1,
+        acquire_alignment=1,
+        qubit_properties=None,
+        concurrent_measurements=None,
+    ):
+        return super().__new__(
+            cls,
+            description=description,
+            num_qubits=num_qubits,
+            dt=dt,
+            granularity=granularity,
+            min_length=min_length,
+            pulse_alignment=pulse_alignment,
+            acquire_alignment=acquire_alignment,
+            qubit_properties=qubit_properties,
+            concurrent_measurements=concurrent_measurements,
+        )
+
+    def __init__(
+        self,
+        coupling_map=None,
+        description=None,  # pylint: disable=unused-argument
+        num_qubits=0,  # pylint: disable=unused-argument
+        dt=None,  # pylint: disable=unused-argument
+        granularity=1,  # pylint: disable=unused-argument
+        min_length=1,  # pylint: disable=unused-argument
+        pulse_alignment=1,  # pylint: disable=unused-argument
+        acquire_alignment=1,  # pylint: disable=unused-argument
+        qubit_properties=None,  # pylint: disable=unused-argument
+        concurrent_measurements=None,  # pylint: disable=unused-argument
+    ):
+        super().__init__()
         if coupling_map is None or isinstance(coupling_map, CouplingMap):
             self._coupling_map = coupling_map
         else:
