@@ -269,6 +269,8 @@ class TestNLocal(QiskitTestCase):
             nlocal = NLocal(1, entanglement_blocks=circuit, reps=1)
         nlocal.assign_parameters(params, inplace=True)
 
+        nlocal = circuit.assign_parameters(params)
+
         param_set = {p for p in params if isinstance(p, ParameterExpression)}
         with self.subTest(msg="Test the parameters of the non-transpiled circuit"):
             # check the parameters of the final circuit
@@ -277,7 +279,7 @@ class TestNLocal(QiskitTestCase):
         with self.subTest(msg="Test the parameters of the transpiled circuit"):
             basis_gates = ["id", "u1", "u2", "u3", "cx"]
             transpiled_circuit = transpile(nlocal, basis_gates=basis_gates)
-            self.assertEqual(transpiled_circuit.parameters, param_set)
+            self.assertEqual(set(transpiled_circuit.parameters), param_set)
 
     def test_repetetive_parameter_setting(self):
         """Test alternate setting of parameters and circuit construction."""
